import { renderless, api } from '@opentinyvue/vue-renderless/progress/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconClose, iconSuccess, iconError, iconYes, iconWarning } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["type", "percentage", "status", "strokeWidth", "textInside", "width", "showText", "color", "format", "size", "info"]),
  components: {
    IconClose: iconClose(),
    IconSuccess: iconSuccess(),
    IconError: iconError(),
    IconYes: iconYes(),
    IconWarning: iconWarning()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: [_vm.type !== "line" && "inline-block text-center"],
    attrs: {
      "role": "progressbar",
      "aria-valuenow": _vm.percentage,
      "aria-valuemin": "0",
      "aria-valuemax": "100",
      "data-tag": "tiny-progress"
    }
  }, [_c("div", {
    staticClass: "relative leading-none",
    class: [_vm.type === "line" ? "flex items-center" : "inline-block"],
    attrs: {
      "data-tag": "tiny-progress-content"
    }
  }, [_vm.type === "line" ? _c("div", {
    staticClass: "box-border inline-block align-middle flex-1",
    class: [!_vm.showText ? "pr-0 mr-0 block" : "", _vm.textInside ? "pr-0 mr-0" : ""],
    attrs: {
      "data-tag": "tiny-progress-line"
    }
  }, [_c("div", {
    staticClass: "rounded-full bg-color-bg-3 overflow-hidden relative align-middle",
    class: [_vm.size === "small" ? "h-1" : "", _vm.size === "medium" ? "h-2" : "", _vm.size === "large" ? "h-4" : ""],
    style: _vm.state.strokeWidth ? {
      height: _vm.state.strokeWidth + "px"
    } : {},
    attrs: {
      "data-tag": "tiny-progress-strokewidth"
    }
  }, [_c("transition", {
    attrs: {
      "appear": "",
      "appear-class": "custom-appear-class"
    },
    on: {
      "before-appear": _vm.customBeforeAppearHook,
      "appear": _vm.customAppearHook,
      "after-appear": _vm.customAfterAppearHook
    }
  }, [_c("div", {
    class: _vm.m("absolute left-0 top-0 h-full bg-color-brand text-right rounded-full leading-none whitespace-nowrap transition-[width] duration-500 ease-in after:content-[''] after:h-full after:inline-block after:align-middle", _vm.status === "success" && "bg-color-success", _vm.status === "warning" && "bg-color-warning", _vm.status === "exception" && "bg-color-error"),
    style: _vm.state.barStyle,
    attrs: {
      "data-tag": "tiny-progress-bar"
    }
  }, [_vm.showText && _vm.textInside ? _c("div", {
    staticClass: "text-color-text-inverse text-xs mr-3 inline-block align-middle"
  }, [_vm._v(" " + _vm._s(_vm.state.content) + " ")]) : _vm._e()])])], 1)]) : _c("div", {
    staticClass: "inline-block",
    class: [_vm.size === "small" && "w-12 h-12", _vm.size === "medium" && "w-24 h-24", _vm.size === "large" && "w-40 h-40"],
    style: _vm.width ? _vm.state.circleStyle : {},
    attrs: {
      "data-tag": "tiny-progress-circle-style"
    }
  }, [_c("svg", {
    attrs: {
      "viewBox": "0 0 100 100"
    }
  }, [_c("path", {
    style: _vm.state.trailPathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": "#E8EBEF",
      "stroke-width": _vm.state.relativeStrokeWidth,
      "fill": "none"
    }
  }), _c("transition", {
    attrs: {
      "appear": "",
      "appear-class": "custom-appear-class"
    },
    on: {
      "before-appear": _vm.customBeforeAppearHook,
      "appear": _vm.customAppearHook,
      "after-appear": _vm.customAfterAppearHook
    }
  }, [_c("path", {
    style: _vm.state.circlePathStyle,
    attrs: {
      "d": _vm.state.trackPath,
      "stroke": _vm.state.stroke,
      "fill": "none",
      "stroke-linecap": "round",
      "stroke-width": _vm.percentage ? _vm.state.relativeStrokeWidth : 0
    }
  })])], 1)]), _vm.showText && !_vm.textInside ? _c("div", {
    class: _vm.m("text-xs inline-block align-middle ml-3 leading-none", !_vm.showText && "hidden", _vm.type !== "line" ? "text-color-text-primary absolute top-1/2 left-0 w-full text-center m-0 translate-x-0 -translate-y-1/2" : "text-color-text-primary"),
    style: {
      fontSize: _vm.state.progressTextSize + "px"
    },
    attrs: {
      "data-tag": "tiny-progress-text"
    }
  }, [!_vm.status ? [_vm.type === "line" ? _c("span", [_vm._v(" " + _vm._s(_vm.state.content) + " ")]) : _c("div", {
    staticClass: "text-[0]"
  }, [_c("span", {
    style: {
      fontSize: _vm.state.progressTextSize + "px"
    }
  }, [_vm._v(_vm._s(typeof _vm.format === "function" ? _vm.state.content : _vm.percentage))]), typeof _vm.format !== "function" ? _c("span", {
    style: {
      fontSize: _vm.state.percentTextSize + "px"
    }
  }, [_vm._v("%")]) : _vm._e()])] : _vm._t(_vm.status + "Icon", function() {
    return [_c(_vm.state.iconClass, {
      tag: "component",
      class: [_vm.status === "success" && "fill-color-success", _vm.status === "warning" && "fill-color-warning", _vm.status === "exception" && "fill-color-error", _vm.size === "small" ? _vm.type === "line" ? "w-3 h-3" : "w-6 h-6" : "", _vm.size === "medium" ? _vm.type === "line" ? "w-4 h-4" : "w-10 h-10" : "", _vm.size === "large" ? _vm.type === "line" ? "w-6 h-6" : "w-20 h-20" : ""],
      style: _vm.state.iconStyle
    })];
  })], 2) : _vm._e()]), _vm.type !== "line" && _vm.info ? _c("div", {
    staticClass: "mt-2 text-center text-sm text-color-text-secondary",
    attrs: {
      "data-tag": "tiny-progress-info"
    }
  }, [_vm._v(" " + _vm._s(_vm.info) + " ")]) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
